@@ -14,4 +14,9 @@ BETA: Final[Environment] = Environment(
 IAE: Final[Environment] = Environment(
     api_endpoint="https://iae.cloud.handcash.io",
     client_url="https://handcash-web.firebaseapp.com",
-)
\ No newline at end of file
+)
+
+PROD: Final[Environment] = Environment(
+    api_endpoint="https://cloud.handcash.io",
+    client_url="https://app.handcash.io",
+)
